@@ -1,8 +1,4 @@
-try:
-    from collections import OrderedDict
-except ImportError:
-    from ordereddict import OrderedDict
-
+from collections import OrderedDict
 from functools import partial
 from inspect import isclass
 from operator import attrgetter
@@ -15,11 +11,16 @@ from sqlalchemy.orm import mapperlib
 from sqlalchemy.orm.attributes import InstrumentedAttribute
 from sqlalchemy.orm.exc import UnmappedInstanceError
 from sqlalchemy.orm.properties import ColumnProperty, RelationshipProperty
-from sqlalchemy.orm.query import _ColumnEntity
+
+try:
+    from sqlalchemy.orm.context import _ColumnEntity, _MapperEntity
+except ImportError:  # SQLAlchemy <1.4
+    from sqlalchemy.orm.query import _ColumnEntity, _MapperEntity
+
 from sqlalchemy.orm.session import object_session
 from sqlalchemy.orm.util import AliasedInsp
 
-from sqlalchemy_utils.utils import is_sequence
+from ..utils import is_sequence
 
 
 def get_class_by_table(base, table, data=None):
@@ -74,7 +75,7 @@ def get_class_by_table(base, table, data=None):
     :return: Declarative class or None.
     """
     found_classes = set(
-        c for c in base._decl_class_registry.values()
+        c for c in _get_class_registry(base).values()
         if hasattr(c, '__table__') and c.__table__ is table
     )
     if len(found_classes) > 1:
@@ -153,6 +154,57 @@ def get_type(expr):
     raise TypeError("Couldn't inspect type.")
 
 
+def cast_if(expression, type_):
+    """
+    Produce a CAST expression but only if given expression is not of given type
+    already.
+
+    Assume we have a model with two fields id (Integer) and name (String).
+
+    ::
+
+        import sqlalchemy as sa
+        from sqlalchemy_utils import cast_if
+
+
+        cast_if(User.id, sa.Integer)    # "user".id
+        cast_if(User.name, sa.String)   # "user".name
+        cast_if(User.id, sa.String)     # CAST("user".id AS TEXT)
+
+
+    This function supports scalar values as well.
+
+    ::
+
+        cast_if(1, sa.Integer)          # 1
+        cast_if('text', sa.String)      # 'text'
+        cast_if(1, sa.String)           # CAST(1 AS TEXT)
+
+
+    :param expression:
+        A SQL expression, such as a ColumnElement expression or a Python string
+        which will be coerced into a bound literal value.
+    :param type_:
+        A TypeEngine class or instance indicating the type to which the CAST
+        should apply.
+
+    .. versionadded: 0.30.14
+    """
+    try:
+        expr_type = get_type(expression)
+    except TypeError:
+        expr_type = expression
+        check_type = type_().python_type
+    else:
+        check_type = type_
+
+    return (
+        sa.cast(expression, type_)
+        if not isinstance(expr_type, check_type)
+        else expression
+    )
+
+
 def get_column_key(model, column):
     """
     Return the key for given column in given model.
@@ -217,11 +269,11 @@ def get_mapper(mixed):
 
     .. versionadded: 0.26.1
     """
-    if isinstance(mixed, sa.orm.query._MapperEntity):
+    if isinstance(mixed, _MapperEntity):
         mixed = mixed.expr
     elif isinstance(mixed, sa.Column):
         mixed = mixed.table
-    elif isinstance(mixed, sa.orm.query._ColumnEntity):
+    elif isinstance(mixed, _ColumnEntity):
         mixed = mixed.expr
 
     if isinstance(mixed, sa.orm.Mapper):
@@ -235,8 +287,14 @@ def get_mapper(mixed):
     if isinstance(mixed, sa.orm.attributes.InstrumentedAttribute):
         mixed = mixed.class_
     if isinstance(mixed, sa.Table):
+        if hasattr(mapperlib, '_all_registries'):
+            all_mappers = set()
+            for mapper_registry in mapperlib._all_registries():
+                all_mappers.update(mapper_registry.mappers)
+        else:  # SQLAlchemy <1.4
+            all_mappers = mapperlib._mapper_registry
         mappers = [
-            mapper for mapper in mapperlib._mapper_registry
+            mapper for mapper in all_mappers
             if mixed in mapper.tables
         ]
         if len(mappers) > 1:
@@ -363,7 +421,7 @@ def get_tables(mixed):
         return [mixed.table]
     elif isinstance(mixed, sa.orm.attributes.InstrumentedAttribute):
         return mixed.parent.tables
-    elif isinstance(mixed, sa.orm.query._ColumnEntity):
+    elif isinstance(mixed, _ColumnEntity):
         mixed = mixed.expr
 
     mapper = get_mapper(mixed)
@@ -403,14 +461,21 @@ def get_columns(mixed):
         SA Table object, SA Mapper, SA declarative class, SA declarative class
         instance or an alias of any of these objects
     """
-    if isinstance(mixed, sa.Table):
-        return mixed.c
+    if isinstance(mixed, sa.sql.selectable.Selectable):
+        try:
+            return mixed.selected_columns
+        except AttributeError:  # SQLAlchemy <1.4
+            return mixed.c
     if isinstance(mixed, sa.orm.util.AliasedClass):
         return sa.inspect(mixed).mapper.columns
-    if isinstance(mixed, sa.sql.selectable.Alias):
-        return mixed.c
     if isinstance(mixed, sa.orm.Mapper):
         return mixed.columns
+    if isinstance(mixed, InstrumentedAttribute):
+        return mixed.property.columns
+    if isinstance(mixed, ColumnProperty):
+        return mixed.columns
+    if isinstance(mixed, sa.Column):
+        return [mixed]
     if not isclass(mixed):
         mixed = mixed.__class__
     return sa.inspect(mixed).columns
@@ -466,109 +531,11 @@ def quote(mixed, ident):
     return dialect.preparer(dialect).quote(ident)
 
 
-def query_labels(query):
-    """
-    Return all labels for given SQLAlchemy query object.
-
-    Example::
-
-
-        query = session.query(
-            Category,
-            db.func.count(Article.id).label('articles')
-        )
-
-        query_labels(query)  # ['articles']
-
-    :param query: SQLAlchemy Query object
-    """
-    return [
-        entity._label_name for entity in query._entities
-        if isinstance(entity, _ColumnEntity) and entity._label_name
-    ]
-
-
-def get_query_entities(query):
-    """
-    Return a list of all entities present in given SQLAlchemy query object.
-
-    Examples::
-
-
-        from sqlalchemy_utils import get_query_entities
-
-
-        query = session.query(Category)
-
-        get_query_entities(query)  # [<Category>]
-
-
-        query = session.query(Category.id)
-
-        get_query_entities(query)  # [<Category>]
-
-
-    This function also supports queries with joins.
-
-    ::
-
-
-        query = session.query(Category).join(Article)
-
-        get_query_entities(query)  # [<Category>, <Article>]
-
-    .. versionchanged: 0.26.7
-        This function now returns a list instead of generator
-
-    :param query: SQLAlchemy Query object
-    """
-    exprs = [
-        d['expr']
-        if is_labeled_query(d['expr']) or isinstance(d['expr'], sa.Column)
-        else d['entity']
-        for d in query.column_descriptions
-    ]
-    return [
-        get_query_entity(expr) for expr in exprs
-    ] + [
-        get_query_entity(entity) for entity in query._join_entities
-    ]
-
-
-def is_labeled_query(expr):
-    return (
-        isinstance(expr, sa.sql.elements.Label) and
-        isinstance(
-            list(expr.base_columns)[0],
-            (sa.sql.selectable.Select, sa.sql.selectable.ScalarSelect)
-        )
-    )
-
-
-def get_query_entity(expr):
-    if isinstance(expr, sa.orm.attributes.InstrumentedAttribute):
-        return expr.parent.class_
-    elif isinstance(expr, sa.Column):
-        return expr.table
-    elif isinstance(expr, AliasedInsp):
-        return expr.entity
-    return expr
-
-
-def get_query_entity_by_alias(query, alias):
-    entities = get_query_entities(query)
-
-    if not alias:
-        return entities[0]
-
-    for entity in entities:
-        if isinstance(entity, sa.orm.util.AliasedClass):
-            name = sa.inspect(entity).name
-        else:
-            name = get_mapper(entity).tables[0].name
-
-        if name == alias:
-            return entity
+def _get_query_compile_state(query):
+    if hasattr(query, '_compile_state'):
+        return query._compile_state()
+    else:  # SQLAlchemy <1.4
+        return query
 
 
 def get_polymorphic_mappers(mixed):
@@ -578,21 +545,6 @@ def get_polymorphic_mappers(mixed):
         return mixed.polymorphic_map.values()
 
 
-def get_query_descriptor(query, entity, attr):
-    if attr in query_labels(query):
-        return attr
-    else:
-        entity = get_query_entity_by_alias(query, entity)
-        if entity:
-            descriptor = get_descriptor(entity, attr)
-            if (
-                hasattr(descriptor, 'property') and
-                isinstance(descriptor.property, sa.orm.RelationshipProperty)
-            ):
-                return
-            return descriptor
-
-
 def get_descriptor(entity, attr):
     mapper = sa.inspect(entity)
 
@@ -617,6 +569,9 @@ def get_descriptor(entity, attr):
             else:
                 # Handle synonyms, relationship properties and hybrid
                 # properties
+
+                if isinstance(entity, sa.orm.util.AliasedClass):
+                    return getattr(entity, attr)
                 try:
                     return getattr(mapper.class_, attr)
                 except AttributeError:
@@ -624,16 +579,20 @@ def get_descriptor(entity, attr):
 
 
 def get_all_descriptors(expr):
+    if isinstance(expr, sa.sql.selectable.Selectable):
+        return expr.c
     insp = sa.inspect(expr)
-    polymorphic_mappers = get_polymorphic_mappers(insp)
-    if polymorphic_mappers:
+    try:
+        polymorphic_mappers = get_polymorphic_mappers(insp)
+    except sa.exc.NoInspectionAvailable:
+        return get_mapper(expr).all_orm_descriptors
+    else:
         attrs = dict(get_mapper(expr).all_orm_descriptors)
         for submapper in polymorphic_mappers:
             for key, descriptor in submapper.all_orm_descriptors.items():
                 if key not in attrs:
                     attrs[key] = descriptor
         return attrs
-    return get_mapper(expr).all_orm_descriptors
 
 
 def get_hybrid_properties(model):
@@ -675,14 +634,27 @@ def get_hybrid_properties(model):
         get_hybrid_properties(Category).keys()  # ['lowercase_name']
 
 
+    This function also supports aliased classes
+
+    ::
+
+
+        get_hybrid_properties(
+            sa.orm.aliased(Category)
+        ).keys()  # ['lowercase_name']
+
+
     .. versionchanged: 0.26.7
         This function now returns a dictionary instead of generator
 
+    .. versionchanged: 0.30.15
+        Added support for aliased classes
+
     :param model: SQLAlchemy declarative model or mapper
     """
     return dict(
         (key, prop)
-        for key, prop in sa.inspect(model).all_orm_descriptors.items()
+        for key, prop in get_mapper(model).all_orm_descriptors.items()
         if isinstance(prop, hybrid_property)
     )
 
@@ -928,3 +900,10 @@ def naturally_equivalent(obj, obj2):
         if not (getattr(obj, column_key) == getattr(obj2, column_key)):
             return False
     return True
+
+
+def _get_class_registry(class_):
+    try:
+        return class_.registry._class_registry
+    except AttributeError:  # SQLAlchemy <1.4
+        return class_._decl_class_registry
