@@ -76,7 +76,7 @@ class Password(Mutable, object):
         return not (self == value)
 
 
-class PasswordType(types.TypeDecorator, ScalarCoercible):
+class PasswordType(ScalarCoercible, types.TypeDecorator):
     """
     PasswordType hashes passwords as they come into the database and allows
     verifying them using a Pythonic interface. This Pythonic interface
@@ -158,9 +158,16 @@ class PasswordType(types.TypeDecorator, ScalarCoercible):
 
         # Construct the passlib crypt context.
         self.context = LazyCryptContext(**kwargs)
-
         self._max_length = max_length
 
+    @property
+    def hashing_method(self):
+        return (
+            'hash'
+            if hasattr(self.context, 'hash')
+            else 'encrypt'
+        )
+
     @property
     def length(self):
         """Get column length."""
@@ -205,21 +212,24 @@ class PasswordType(types.TypeDecorator, ScalarCoercible):
 
     def process_bind_param(self, value, dialect):
         if isinstance(value, Password):
-            # If were given a password secret; encrypt it.
+            # If were given a password secret; hash it.
             if value.secret is not None:
-                return self.context.encrypt(value.secret).encode('utf8')
+                return self._hash(value.secret).encode('utf8')
 
             # Value has already been hashed.
             return value.hash
 
         if isinstance(value, six.string_types):
             # Assume value has not been hashed.
-            return self.context.encrypt(value).encode('utf8')
+            return self._hash(value).encode('utf8')
 
     def process_result_value(self, value, dialect):
         if value is not None:
             return Password(value, self.context)
 
+    def _hash(self, value):
+        return getattr(self.context, self.hashing_method)(value)
+
     def _coerce(self, value):
 
         if value is None:
@@ -227,16 +237,16 @@ class PasswordType(types.TypeDecorator, ScalarCoercible):
 
         if not isinstance(value, Password):
             # Hash the password using the default scheme.
-            value = self.context.encrypt(value).encode('utf8')
+            value = self._hash(value).encode('utf8')
             return Password(value, context=self.context)
 
         else:
             # If were given a password object; ensure the context is right.
             value.context = weakref.proxy(self.context)
 
-            # If were given a password secret; encrypt it.
+            # If were given a password secret; hash it.
             if value.secret is not None:
-                value.hash = self.context.encrypt(value.secret).encode('utf8')
+                value.hash = self._hash(value.secret).encode('utf8')
                 value.secret = None
 
         return value
