@@ -1,6 +1,8 @@
-class ScalarCoercible(object):
+class ScalarCoercible:
+    cache_ok = True
+
     def _coerce(self, value):
-        raise NotImplemented
+        raise NotImplementedError
 
     def coercion_listener(self, target, value, oldvalue, initiator):
         return self._coerce(value)
